@@ -482,7 +482,7 @@ class Attention(nn.Module):
         self.norm = nn.LayerNorm(dim)
 
         self.to_q = nn.Linear(dim, inner_dim, bias = False)
-        self.to_kv = nn.Linear(dim, inner_dim * 2, bias = False)
+        self.to_kv = nn.Linear(dim, dim_head * 2, bias = False)
         self.to_out = nn.Linear(inner_dim, dim, bias = False)
 
     def forward(self, x, attn_bias = None):
@@ -490,11 +490,11 @@ class Attention(nn.Module):
 
         q, k, v = self.to_q(x), *self.to_kv(x).chunk(2, dim = -1)
 
-        q, k, v = map(lambda t: rearrange(t, 'b n (h d) -> b h n d', h = self.heads), (q, k, v))
+        q = rearrange(q, 'b n (h d) -> b h n d', h = self.heads)
 
         q = q * self.scale
 
-        sim = einsum('b h i d, b h j d -> b h i j', q, k)
+        sim = einsum('b h i d, b j d -> b h i j', q, k)
 
         if exists(attn_bias):
             sim = sim + attn_bias
@@ -505,7 +505,7 @@ class Attention(nn.Module):
 
         attn = sim.softmax(dim = -1)
 
-        out = einsum('b h i j, b h j d -> b h i d', attn, v)
+        out = einsum('b h i j, b j d -> b h i d', attn, v)
 
         out = rearrange(out, 'b h n d -> b n (h d)')
         return self.to_out(out)
